/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 1991-2005 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Class
    polyMeshBandCompression

Description
    the class holds the information necessary to renumber the mesh in such a way
    that the band of the matrix is reduced. The algorithm uses a simple search
    through the neighbour list

SourceFiles
    polyMeshBandCompression.C
    polyMeshBandCompressionRenumberField.C

\*---------------------------------------------------------------------------*/

#ifndef polyMeshBandCompression_H
#define polyMeshBandCompression_H

#include "polyMesh.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                      Class polyMeshBandCompression Declaration
\*---------------------------------------------------------------------------*/

class polyMeshBandCompression
:
    public polyMesh
{
    // Private data

        //- New cell order for the compressed band
        labelList cellOrder_;

    // Private Member Functions

        //- Disallow default bitwise copy construct
        polyMeshBandCompression(const polyMeshBandCompression&);

        //- Disallow default bitwise assignment
        void operator=(const polyMeshBandCompression&);


public:


    // Constructors

        //- Construct from IOobject
    polyMeshBandCompression
    (
        const IOobject& io, const pointField& points,
        const cellShapeList& shapes, const faceListList& boundaryFaces,
        const wordList& boundaryPatchNames, const wordList& boundaryPatchTypes,
        const word& defaultBoundaryPatchType,
        const wordList& boundaryPatchPhysicalTypes
    );


    // Member Functions

        //- Return new cell order.
        // This gives the order in which the cells in the original mesh
        // are to be addressed to create a mesh with a compressed band
        const labelList& cellOrder() const
        {
            return cellOrder_;
        }

        //- Return pointer to renumbered mesh created on freestore
        polyMesh* renumberedMesh() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
